<?php

namespace Ecommerce\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response;
use Ecommerce\Services\AutorizacaoFornecimentoService;
use Ecommerce\Controllers\ExportaXmlMercadoEletronico;

class AutorizacaoFornecimentoController 
{
    protected $newCodeSC;
    protected $autorizacaoFornecimentoService;
    protected $utilities;
    protected $exportaXmlMercadoEletronico;
    
    public function __construct($newCodeSC, $autorizacaoFornecimentoService, $utilities, $exportaXmlMercadoEletronico)
    {
        $this->newCodeSC = $newCodeSC;
        $this->autorizacaoFornecimentoService = $autorizacaoFornecimentoService;
        $this->utilities = $utilities;
        $this->exportaXmlMercadoEletronico = $exportaXmlMercadoEletronico;
	}
	
	function getLabels(DTO\Request $request, DTO\Response $response) 
	{
	    try {
    	    $row = $request->getRow();
    	    $result = $this->autorizacaoFornecimentoService->getLabels($row);
    	    $response->addDataset(new DataSet('etiquetas', $result));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 1));
        }
	}
	
	function saveLabel(DTO\Request $request, DTO\Response $response) 
	{
	    try {
    	    $row = $request->getRow();
    	    $exist = $this->autorizacaoFornecimentoService->checkLabelExist($row);
    	    if (sizeof($exist)) {
    	        throw new \Exception('Já existe uma etiqueta com este nome cadastrada.');
    	    } else {
    	        $newCode = (int)$this->newCodeSC->getCodeByTableName('ETIQUETAECOMMERCE', $row['P_NRORG']);
    	        $this->autorizacaoFornecimentoService->saveLabel($row, $newCode);
    	    }
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 1));
        }
	}
	
	function deleteLabel(DTO\Request $request, DTO\Response $response) 
	{
	    try {
    	    $row = $request->getRow();
    	    $this->autorizacaoFornecimentoService->deleteLabel($row);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 1));
        }
	}
	
	function bindLabels(DTO\Request $request, DTO\Response $response) 
	{
	    try {
    	    $row = $request->getRow();
    	    $this->autorizacaoFornecimentoService->unbindLabels($row);
    	    $this->autorizacaoFornecimentoService->bindLabelsAF($row);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 1));
        }
	}
	
	function unbindLabels(DTO\Request $request, DTO\Response $response) 
	{
	    try {
    	    $row = $request->getRow();
    	    $this->autorizacaoFornecimentoService->unbindLabels($row);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 1));
        }
	}
	
	private function substituiCaracteres($valor)
	{
	    $retirar = array('<', '>', '"', '\'', '&lt;', '&gt;', '“', '”', '&nbsp;', '&amp;');
        $substituir = array('', '', '', '', '', '', '', '', ' ', '&');
	    
	    $valor = strip_tags($valor);
        
        $valor = str_replace($retirar, $substituir, $valor);
        
        if (mb_detect_encoding($valor) != 'UTF-8') {
            $valor = utf8_encode($valor);
        }
        
        return htmlspecialchars($valor);
	}
	
	private function retornaTipoColuna($valor)
    {
        $listaTipos = array(
            "string" => "String",
            "double" => "Float",
            "integer" => "Integer"
        );
        
        $tipo = gettype($valor);

        return $listaTipos[$tipo];
    }
    
    private function quebraArquivoAF($quebraXmlAf, &$dom, &$elementoLoteAf, &$loteAf, $pedido)
    {
        if ($quebraXmlAf) {
    
            $dom->appendChild($elementoLoteAf);
            $loteAf[$pedido] = $dom->saveXml();
            
            $dom->removeChild($elementoLoteAf);
            $elementoLoteAf = $dom->createElement("MEBrokerXMLMessage");
            
        }
    }

    public function exportarXml(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();
        
        try {
            $this->autorizacaoFornecimentoService->iniciaTransacao();
            
            switch ($row['REPORT_NAME']) {
                case 'ME':
                    $xml = $this->exportarXmlME($row);
                    break;
                case 'PLANILHA_ALTERACAO':
                    $xml = $this->exportarXmlPlanilhaAlteracao($row);
                    break;
            }

            self::processaAfsBaixadas($row);
            
            $this->autorizacaoFornecimentoService->commit();

            $response->addMessage(new Response\Message($xml));
        } catch (\Exception $e) {
            $this->autorizacaoFornecimentoService->rollback();
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    
    private function exportarXmlME ($row)
    {
        $afs = array();
        $paramFixo = array("CDFORNECED" => $row['CDFORNECED']);
        $paramConcat = array(
            "NRAUTOFORN" => "",
            "CDFILDEST" => "",
            "CDFILLANC" => ""
        );
        
        $paramDadosAf = $this->montaParamDadosAfPaginacao($row['AFS_SELECIONADAS'], $paramFixo, $paramConcat);
            
        $xml = $this->exportaXmlMercadoEletronico->exportarXml($paramDadosAf, $row['QUEBRA_XML_AF']);
        
        return $xml;
    }
    
    private function exportarXmlPlanilhaAlteracao ($row)
    {
        $afs = array();
        
        $paramFixo = array("CDFORNECED" => $row['CDFORNECED']);
        $paramConcat = array(
            "NRLOGPLANITEMAF" => "",
            "CDFILDEST" => "",
            "NRSEQAPURAF" => "",
            "CDFILLANC" => "",
            "NRSEQENVIOAFORN" => "",
            "NRAUTOFORN" => ""
        );
            
        $paramDadosAf = $this->montaParamDadosAfPaginacao($row['AFS_SELECIONADAS'], $paramFixo, $paramConcat);
        
        foreach ($paramDadosAf as $param) {
            $af = $this->autorizacaoFornecimentoService->retornaAfsPlanilhaAlteracao($param);
            $afs = array_merge($afs, $af);
        }
        
        $xml = $this->converteArrayXmlPlanilhaAlteracao($afs, $row['QUEBRA_XML_AF']);
        
        return $xml;
    }
    
    private function montaParamDadosAfPaginacao ($afsSelecionadas, $paramFixo, $paramConcat)
    {
        $params = array();
        $param = $paramConcat;
        $pagina = 150;
        $paginacao = $pagina;
        
        foreach ($afsSelecionadas as $index => $af) {
            if ($index < $paginacao) {
                foreach ($paramConcat as $nome => $value) {
                    $param[$nome] .= $af[$nome] ? $af[$nome] . '_' : '';
                }
            } else {
                $param = array_merge($param, $paramFixo);
                array_push($params, $param);
                
                foreach ($paramConcat as $nome => $value) {
                    $param[$nome] = $af[$nome] ? $af[$nome] . '_' : '';
                }
                
                $paginacao += $pagina;
            }
        }
        
        $param = array_merge($param, $paramFixo);
        array_push($params, $param);
        
        return $params;
    }
    
    private function converteArrayXmlPlanilhaAlteracao ($afs, $quebraXmlAf)
    {
        $dom = new \DOMDocument("1.0", "UTF-8");
        
        $dom->preserveWhiteSpace = false;
        $dom->formatOutput = true;
        
        $elementoPlanilhaAlteracao = $dom->createElement("PLANILHA_ALTERACAO");
        
        $this->preencheElementoAF($dom, $elementoAF, reset($afs));
        $elementoProdutos = $dom->createElement('PRODUTOS');
        
        $afAnterior = isset($afs[0]['AF_NUMERO_DA_AF']) ? $afs[0]['AF_NUMERO_DA_AF'] : false;
        
        foreach ($afs as $af) {
            if ($af['AF_NUMERO_DA_AF'] !== $afAnterior) {
                $elementoAF->appendChild($elementoProdutos);
                $elementoPlanilhaAlteracao->appendChild($elementoAF);
                
                if ($quebraXmlAf) {
                    $dom->appendChild($elementoPlanilhaAlteracao);
                    $planilhaAlteracao[$afAnterior] = $dom->saveXml();
                
                    $dom->removeChild($elementoPlanilhaAlteracao);
                    $elementoPlanilhaAlteracao = $dom->createElement("PLANILHA_ALTERACAO");
                }

                $this->preencheElementoAF($dom, $elementoAF, $af);
                $elementoProdutos = $dom->createElement('PRODUTOS');
                
                $afAnterior = $af['AF_NUMERO_DA_AF'];
            }
            
            $elementoItemAF = $dom->createElement('ITEM');
            
            $this->preencheElemento($af, 'ITEM_', $dom, $elementoItemAF);
            
            $elementoProdutos->appendChild($elementoItemAF);
        }
        
        $elementoAF->appendChild($elementoProdutos);
        $elementoPlanilhaAlteracao->appendChild($elementoAF);
        
        $dom->appendChild($elementoPlanilhaAlteracao);
        
        $nomeIndice = $quebraXmlAf ? $af['AF_NUMERO_DA_AF'] : 'RelatorioAF';
        $planilhaAlteracao[$nomeIndice] = $dom->saveXml();
        
        return $planilhaAlteracao;
    }
    
    private function preencheElemento ($af, $prefixo, &$dom, &$elemento)
    {
        foreach ($af as $nome=>$valor) {
            if (strpos($nome, $prefixo) !== false) {
                $nome = str_replace($prefixo, '', $nome);
                $valor = $this->substituiCaracteres($valor);
                
                $elemento->appendChild($dom->createElement($nome, $valor));
            }
        }
    }
    
    private function preencheElementoAF (&$dom, &$elementoAF, $af)
    {
        $numeroAF = $af['AF_NUMERO_DA_AF'];
        
        $elementoAF = $dom->createElement("AF_$numeroAF");

        $this->preencheElemento($af, 'AF_', $dom, $elementoAF);
    }
    
    public function processaAfsBaixadas($dados) 
    {
        $afsBaixadas = $dados['AFS_SELECIONADAS'];
        
        foreach ($afsBaixadas as $af) {
        
            self::insereLogdownloadaf($af, $dados['DSLOGINECO']);
        }
        
        //CODIGO RETIRADO ATE DEFINIR O QUE SERA FEITO
        //ADICIONAR OS PARAMETROS "NRSEQAPURAF" E "NRSEQENVIOAFORN" NO METODO montaParamDadosAfPaginacao E ENVIAR O RETORNO PARA ESTE METODO
        /*$loteStatusAlterado = self::atualizaStatusLoteAf($dados);
        
        //VERIFICAR QUAL FILIAL SERA UTILIZADA PARA PEGAR O LGPD
        self::enviaEmailComprador($loteStatusAlterado, $dados['CDFORNECED'], $dados['NMFANTFORN'], $dados['NMUSUARIOECO']);*/
        
    }
    
    function insereLogdownloadaf($af, $dslogineco)
    {
        //$nrseqdownloadaf = $this->newCodeSC->getCodeByTableName('LOGDOWNLOADAF', 1, 1, 20);

        $this->autorizacaoFornecimentoService->insereLogdownloadaf( $af['NRSEQENVIOAFORN'], $af['CDFORNECED'], $af['NRAUTOFORN'], $af['CDFILDEST'], $af['CDFILLANC'], $dslogineco);
    }
    
    function atualizaStatusLoteAf($dados)
    {
        $loteStatusAlterado = '';
        
        foreach ($dados as $dado) {
            $afsLidas = $this->autorizacaoFornecimentoService->retornaAfsLidas($dado);

            foreach ($afsLidas as $afLida) {
                if ($afLida['IDTIPENVLIDO'] == 'N') {
                    $this->autorizacaoFornecimentoService->atualizaStatusLoteAf($afLida['NRSEQENVIOAFORN'], $dado['CDFORNECED']);
                    $loteStatusAlterado .= $afLida['NRSEQENVIOAFORN'] . '_';
                }
            }
        }
        
        return $loteStatusAlterado;
    }
    
    // function enviaEmailComprador($loteStatusAlterado, $cdforneced, $nmfantforn, $nmusuarioeco)
    // {
    //     if ($loteStatusAlterado) {
    //         $listaEnvioEmail = $this->autorizacaoFornecimentoService->retornaEmailComprador($loteStatusAlterado, $cdforneced);

    //         if (count($listaEnvioEmail)) {
    //             $this->smtpUtil->setSubject("Visualização de AF's");
                
    //             $data = date('d/m/Y H:i:s');
    //             $assunto = "AF's Totalmente Baixadas";
    //             $mensagem = "Os seguintes lotes de AF foram totalmente baixados pelo fornecedor $nmfantforn através do operador logado $nmusuarioeco no dia $data.<br/><br/> Lotes baixados:";
                
    //             $listaLotes = "<ul>";
    //             $emailAnterior = $listaEnvioEmail[0]['DSEMAILOPER'];
                
    //             foreach ($listaEnvioEmail as $dadosEnvioEmail) {
    //                 if ($emailAnterior == $dadosEnvioEmail['DSEMAILOPER']) {
    //                     $listaLotes .= "<li>" . $dadosEnvioEmail['NRSEQAPURAF'] . "</li>";
    //                 } else {
    //                     $listaLotes .= "</ul>";
                        
    //                     $email = $mensagem . $listaLotes;
    //                     $email = $this->utilities->messageSendMail($cdFilial, $assunto, $email);
                    
    //                     $this->smtpUtil->sendMail($email, $dadosEnvioEmail['DSEMAILOPER']);
                        
    //                     $listaLotes = "<ul>" . "<li>" . $dadosEnvioEmail['NRSEQAPURAF'] . "</li>";
    //                     $emailAnterior = $dadosEnvioEmail['DSEMAILOPER'];
    //                 }
    //             }
                
    //             $listaLotes .= "</ul>";
                
    //             $email = $mensagem . $listaLotes;
    //             $email = $this->utilities->messageSendMail($cdFilial, $assunto, $email);
                
    //             $this->smtpUtil->sendMail($email, $dadosEnvioEmail['DSEMAILOPER']);
    //         }
    //     }
    // }
    
    private function createReturnArrayConfirmaAF($updateAF, $email = array())
    {
        return array(
            "UPDATEAF" => array(
                "MESSAGE" => $updateAF["MESSAGE"],
                "STATUS" => $updateAF["STATUS"]
            ),
            "SENDMAIL" => array(
                "MESSAGE" => isset($email["MESSAGE"]) ? $email["MESSAGE"] : "errorMailProcessBefore",
                "ERROR" => isset($email["ERROR"]) ? $email["ERROR"] : "",
                "STATUS" => isset($email["ERROR"]) ? "error" : "success",
            )
        );
    }
    
    public function confirmarAF(DTO\Request\Row $request, DTO\Response $response)
    {
        $rows = $request->getRow();
        
        $AFs = $this->updateConfirmaAF($rows);
	    
        if (isset($AFs["ERROR"]) && $AFs["ERROR"] == false) {
            if (isset($AFs["PARCIAIS"]) && sizeof($AFs["PARCIAIS"]) > 0) {
                $email = $this->enviaEmailConfirmaAF($rows, $AFs);
                $return = $this->createReturnArrayConfirmaAF($AFs, $email);
                $response->addDataset(new DataSet("MESSAGES", $return));
            }
        } else {
            $return = $this->createReturnArrayConfirmaAF($AFs);
            $response->addDataset(new DataSet("MESSAGES", $return));
        }
    }
    
    private function updateConfirmaAF($rows)
    {
        try {
            $AFsConfirmadas = array();
            $AFsParciais = array();
            $AFsProdutos = array();
            
            $this->autorizacaoFornecimentoService->iniciaTransacao();
            
            foreach ($rows['SELECTEDROWS'] as $selectedRow) {
                $produtos = $this->autorizacaoFornecimentoService->updateConfirmaAF($selectedRow);
                
                if (!empty($produtos)) {
    	            array_push($AFsParciais, $selectedRow);
    	            array_push($AFsProdutos, $produtos);
    	        } else {
                    array_push($AFsConfirmadas, $selectedRow);
    	        }
            }
            
            $this->autorizacaoFornecimentoService->commit();
            
            return array(
                "CONFIRMADAS" => $AFsConfirmadas, 
                "PARCIAIS" => array(
                    "AFS" => $AFsParciais,
                    "PRODUTOS" => $AFsProdutos
                ),
                "MESSAGE" => "successConfirmAF", 
                "STATUS" => "success",
                "ERROR" => false
            );
        } catch (\Exception $e) {
		    $this->autorizacaoFornecimentoService->rollback();
			return array("MESSAGE" => "errorConfirmAF", "STATUS" => "error", "ERROR" => true);
	    }
    }
    
    private function enviaEmailConfirmaAF($rows, $AFs)
    {
        $emailConfirmaAF = $this->autorizacaoFornecimentoService->retornaParamAtendEmailResponsavel($rows['SELECTEDROWS'][0]['CDFORNECED']);
        
        try {
            $listaEmails = $this->retornaEmails($emailConfirmaAF['DSEMAILNOTIFATENDAF']);
            $nmFantForn = $rows['NMFANTFORN'];
            $callback = array();
            $errorMessage = "";
            
            /* 
            *** Função original que envia e-mail para as AFs Confirmadas Totalmente e Parcialmente
            *** Descomentar o bloco abaixo e comentar o if abaixo que envia apenas para as parciais.
            
            // if (!empty($AFs["CONFIRMADAS"])) {
            //     $callback = $this->enviaEmailConfirmadas($AFs["CONFIRMADAS"], $listaEmails, $nmFantForn);
            // }
            
            // if (isset($callback["ERROR"]) && $callback["ERROR"] != false) {
            //     return array("MESSAGE" => $callback["MESSAGE"], "ERROR" => $callback["ERROR"]);
            // } else {
            //     if (!empty($AFs["PARCIAIS"]["AFS"]) && !empty($AFs["PARCIAIS"]["PRODUTOS"])) {
            //         foreach ($AFs["PARCIAIS"]["AFS"] as $i => $parcial) {
            //             $callback = $this->enviaEmailParciais($parcial, $AFs["PARCIAIS"]["PRODUTOS"][$i], $listaEmails, $nmFantForn);
                        
            //             if ($callback["ERROR"] != false) {
            //                 return array("MESSAGE" => $callback["MESSAGE"], "ERROR" => $callback["ERROR"]);
            //             }
            //         }
            //     }
            // }
            
            */
            if (!empty($AFs["PARCIAIS"]["AFS"]) && !empty($AFs["PARCIAIS"]["PRODUTOS"])) {
                foreach ($AFs["PARCIAIS"]["AFS"] as $i => $parcial) {
                    $callback = $this->enviaEmailParciais($parcial, $AFs["PARCIAIS"]["PRODUTOS"][$i], $listaEmails, $nmFantForn);
                    
                    if ($callback["ERROR"] != false) {
                        return array("MESSAGE" => $callback["MESSAGE"], "ERROR" => $callback["ERROR"]);
                    }
                }
            }
            return array("MESSAGE" => "successSendMail", "ERROR" => false);
        } catch (\Exception $e) {
			return array("MESSAGE" => "errorSendMail", "ERROR" => $e->getMessage());
	    }
    }
    
    private function enviaEmailConfirmadas($AFsConfirmadas, $listaEmails, $nmFantForn)
    {
        try {
            $assunto = 'AF(s) Confirmada(s)';
            $mensagem = $this->montaMensagemConfirmadas($AFsConfirmadas, $nmFantForn);
            $this->utilities->setUnitId($AFsConfirmadas[0]['CDFILDEST']);
            $this->utilities->sendMail($assunto, $mensagem, $listaEmails);
            return array("MESSAGE" => "successSendMail", "ERROR" => false);
        } catch (\Exception $e) {
			return array("MESSAGE" => "errorSendMail", "ERROR" => $e->getMessage());
	    }
    }
    
    private function montaMensagemConfirmadas($AFsConfirmadas, $nmFantForn)
    {
        $mensagem = "<div>
                    	<table>
                    		<tr>
                    			<td class='title'> 
                    				<div>
                    					<br/> Prezado,
                    				</div>
                    			</td>
                    		</tr>
                    		<tr>
                    			<td class='description'>
                    				<span>
                    				    O fornecedor " . $nmFantForn . " confirmou a(s) seguinte(s) AF(s):
                    				</span>
                    				<br/></br>
                    				<ul>";
                    				
        foreach ($AFsConfirmadas as $AFConfirmada) {
            if ($AFConfirmada['IDSITUATENDIMENTOAF'] != 'R' && $AFConfirmada['IDSITUATENDIMENTOAF'] != 'P') {
                $mensagem .= "<li>" . $AFConfirmada['NRAUTOFORN'] . " - Unidade: " . $AFConfirmada['FILIAL'] . "</li>";
            }
        }
        
        $mensagem .= "              </ul>
            			        </td>
                    		</tr>
                    		<tr class='footer'>
                    			<td>
                    				<center>
                    					<br> <p> Email automático enviado pelo Portal E-commerce. </p> 
                    				</center>
                    			</td>
                    		</tr>
                    	</table>
                    </div>";
        
        return $mensagem;
    }
    
    private function enviaEmailParciais($AFsParciais, $produtos, $listaEmails, $nmFantForn)
    {
        try {
            $assunto = 'AF Confirmada Parcialmente';
            $mensagem = $this->montaMensagemParciais($AFsParciais, $produtos, $nmFantForn);
            
            if ($mensagem == "") {
                return array("MESSAGE" => "errorSendMail", "ERROR" => "Mensagem vazia.");
            }
            
            $this->utilities->setUnitId($AFsParciais['CDFILDEST']);
            $this->utilities->sendMail($assunto, $mensagem, $listaEmails);
            return array("MESSAGE" => "successSendMail", "ERROR" => false);
        } catch (\Exception $e) {
			return array("MESSAGE" => "errorSendMail", "ERROR" => $e->getMessage());
	    }
    }
    
    private function montaMensagemParciais($AFsParciais, $produtos, $nmFantForn)
    {
        $mensagem = "";

        if ($AFsParciais['IDSITUATENDIMENTOAF'] != 'R' && $AFsParciais['IDSITUATENDIMENTOAF'] != 'C') {
            $mensagem = "<div>
                        	<table>
                        		<tr>
                        			<td class='title'> 
                        				<div>
                        					<br/> Prezado,
                        				</div>
                        			</td>
                        		</tr>
                        		<tr>
                        			<td class='description'>
                        				<span>
                        				    O fornecedor $nmFantForn confirmou parcialmente a(s) AF(s) e recusou o(s) seguinte(s) produto(s):
                        				    <br/></br> <h5> AF " . $AFsParciais['NRAUTOFORN'] . ", na Unidade " . $AFsParciais['FILIAL'] . "</h5>
                        				</span>
                        				<ul>";
            foreach ($produtos as $produto) {
                $mensagem .= "<li>" . $produto['CDARVPROD'] . " - " . $produto['NMPRODUTO'] . "</li>";
            }
            
            $mensagem .= "              </ul>
                			        </td>
                        		</tr>
                        		<tr class='footer'>
                        			<td>
                        				<center>
                        					<br> <p> Email automático enviado pelo Portal E-commerce. </p> 
                        				</center>
                        			</td>
                        		</tr>
                        	</table>
                        </div>";
        }
        
        return $mensagem;
    }
    
    private function createReturnArrayRecusaAF($authOperator, $refuseAF = array(), $sendMail = array())
    {
        return array(
            "AUTHOPERATOR" => array(
                "MESSAGE" => $authOperator["MESSAGE"],
                "STATUS" => $authOperator["STATUS"]
            ),
            "REFUSEAF" => array(
                "MESSAGE" => isset($refuseAF["MESSAGE"]) ? $refuseAF["MESSAGE"] : "errorProcessBefore",
                "STATUS" => isset($refuseAF["STATUS"]) ? $refuseAF["STATUS"] : "success",
            ),
            "SENDMAIL" => array(
                "MESSAGE" => isset($sendMail["MESSAGE"]) ? $sendMail["MESSAGE"] : "errorMailProcessBefore",
                "ERROR" => isset($sendMail["ERROR"]) ? $sendMail["ERROR"] : "",
                "STATUS" => isset($sendMail["STATUS"]) ? $sendMail["STATUS"] : "success",
            )
        );
    }
    
    public function autenticaOperador(DTO\Request\Row $request, DTO\Response $response) 
    {
        $row = $request->getRow();
        
		$authOperator = $this->autorizacaoFornecimentoService->validatePassword($row['OPERADORLOGADO'], $row['SENHA']);
        
        if (isset($authOperator["ERROR"]) && $authOperator["ERROR"] == false) {
            $refuseAF = $this->confirmarRecusaAF($row);
            
            if (isset($refuseAF["ERROR"]) && $refuseAF["ERROR"] == false) {
                $email = $this->enviaEmailRecusaAF($row);
                $return = $this->createReturnArrayRecusaAF($authOperator, $refuseAF, $email);
                $response->addDataset(new DataSet("MESSAGES", $return));
            } else {
                $return = $this->createReturnArrayRecusaAF($authOperator, $refuseAF);
                $response->addDataset(new DataSet("MESSAGES", $return));
            }
        } else {
            $return = $this->createReturnArrayRecusaAF($authOperator);
            $response->addDataset(new DataSet("MESSAGES", $return));
        }
    }
    
    private function confirmarRecusaAF($row)
    {
        try {
            $this->autorizacaoFornecimentoService->iniciaTransacao();
            $this->autorizacaoFornecimentoService->updateRecusaAF($row);
            $this->autorizacaoFornecimentoService->commit();
            
            return array("MESSAGE" => "successRefuseAF", "STATUS" => "success", "ERROR" => false);
        } catch (\Exception $e) {
            $this->autorizacaoFornecimentoService->rollback();
            return array("MESSAGE" => "errorRefuseAF", "STATUS" => "error", "ERROR" => true);
        }
    }
    
    public function enviaEmailRecusaAF($row)
    {
        try {
            $listaEmails = $this->retornaEmails($row['DSEMAILNOTIFATENDAF']);
            $assunto = 'AF(s) Recusada(s)';
            $mensagem = $this->montaMensagemRecusadas($row);
            $this->utilities->setUnitId($row['SELECTEDROWS'][0]['CDFILDEST']);
            $this->utilities->sendMail($assunto, $mensagem, $listaEmails);
            return array("MESSAGE" => "successSendMail", "STATUS" => "success", "ERROR" => false);
        } catch (\Exception $e) {
			return array("MESSAGE" => "errorSendMail", "STATUS" => "alert", "ERROR" => $e->getMessage());
	    }
    }
    
    private function montaMensagemRecusadas($row)
    {
        $mensagem = "<div>
                    	<table>
                    		<tr>
                    			<td class='title'> 
                    				<div>
                    					<br/> Prezado,
                    				</div>
                    			</td>
                    		</tr>
                    		<tr>
                    			<td class='description'>
                    				<span>
                    				    O fornecedor " . $row["NMFANTFORN"] . " recusou a(s) seguinte(s) AF(s):
                    				</span>
                    				<br/></br>
                    				<ul>";
                    				
        foreach ($row['SELECTEDROWS'] as $rowSelected) {
            if($rowSelected['IDSITUATENDIMENTOAF'] != 'R' && $rowSelected['IDSITUATENDIMENTOAF'] != 'C' && $rowSelected['IDSITUATENDIMENTOAF'] != 'P'){
                $mensagem .= "<li>" . $rowSelected['NRAUTOFORN'] . " - Unidade: " . $rowSelected['FILIAL'] . "</li>";
            }
        }
        
        $mensagem .= "              </ul>
            			        </td>
                    		</tr>
                    		<tr>
                                <td>
                                     Justificativa: " . $row['TXJUSTIFICATIVA'] . "
                                </td>
                            </tr>
                    		<tr class='footer'>
                    			<td>
                    				<center>
                    					<br> <p> Email automático enviado pelo Portal E-commerce. </p> 
                    				</center>
                    			</td>
                    		</tr>
                    	</table>
                    </div>";
        
        return $mensagem;
    }
    
    public function retornaEmails($emails)
    {
        $listaEmails = array();
        $listaEmails = array_merge($listaEmails, explode(',', $emails));
        return $listaEmails;
    }
    
    public function confirmarRecusa(DTO\Request $request, DTO\Response $response){
	    $row = $request->getRow();
	    try{
	        $this->autorizacaoFornecimentoService->iniciaTransacao();
	        $this->autorizacaoFornecimentoService->updateRecusaProduto($row);
	        $this->autorizacaoFornecimentoService->commit();
	    } catch (\Exception $e) {
            $this->autorizacaoFornecimentoService->rollback();
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    
    public function confirmarRecusaItens(DTO\Request $request, DTO\Response $response){
	    $row = $request->getRow();
	    try{
	        $this->autorizacaoFornecimentoService->iniciaTransacao();
	        $this->autorizacaoFornecimentoService->updateRecusaItens($row);
	        $this->autorizacaoFornecimentoService->commit();
	    } catch (\Exception $e) {
            $this->autorizacaoFornecimentoService->rollback();
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    
    public function confirmarItensAF(DTO\Request $request, DTO\Response $response){
	    $row = $request->getRow();
	    try{
	        $this->autorizacaoFornecimentoService->iniciaTransacao();
	        $this->autorizacaoFornecimentoService->updateConfirmaItens($row);
	        $this->autorizacaoFornecimentoService->commit();
	    } catch (\Exception $e) {
            $this->autorizacaoFornecimentoService->rollback();
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    
    public function retornaParamAtendEmailResponsavel(DTO\Request $request, DTO\Response $response){
        $row = $request->getRow();
        $result = $this->autorizacaoFornecimentoService->retornaParamAtendEmailResponsavel($row['CDFORNECED']);
        $response->addDataset(new DataSet('data', $result));
    }
    
	public function saveCollectedData(DTO\Request\Row $request, DTO\Response $response)
    {
        try{
            $row = $request->getRow();
            $this->autorizacaoFornecimentoService->saveCollectedData($row);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 1));
        } 
    }
}