<?php
namespace Ecommerce\Services;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;

class AdministradorEmail {
    protected $crudService;
    protected $utilities;
    protected $entityManager;
    
    public function __construct($crudService, $utilities, $entityManager){
        $this->crudService = $crudService;
        $this->utilities = $utilities;
        $this->entityManager = $entityManager;
	}
	
	public function enviarEmail($row, $response) 
	{
        try {
            $row['CDFILIAL'] = $this->utilities->getFilialParasupri();
            
            $permissoes = array(
                "S" => "Autorizada",
                "N" => "Não autorizada"
            );
            
            $dadosMensagem = array(
                'data'        => date("d/m/Y"),
                'address'     => $row["DSLOGINECO"],
                'operador'    => $row["OPERLOGADO"],
                'email'       => $row["DSLOGINECO"],
                'senha'       => $row["CDSENHAWEB"],
                'idAcessoAF'  => $permissoes[$row["IDACESSOAF"]],
                'idAcessoCR'  => $permissoes[$row["IDACESSOCR"]],
                'idAcessoCOT' => $permissoes[$row["IDACESSOCOT"]],
                'motivo'      => $row["MOTIVO_EMAIL"]
            );
            
            $assunto = "";
            $permissoesHTML = "";
            $dadosAcessoHTML = "";
            
            switch ($dadosMensagem['motivo']) {
                case 'exclusao':
                    $subject = "Exclusão de Acesso ao Portal";
                    $cabecalhoHTML = $this->getCabecalho($dadosMensagem, 'exclusao', $assunto);
                break;
                    
                case 'edicao_permissao':
                    $subject = "Alteração nas Permissões de Acesso";
                    $cabecalhoHTML = $this->getCabecalho($dadosMensagem, 'edicao_permissao', $assunto);
                    $permissoesHTML = $this->getPermissoes($dadosMensagem);
                break;
                
                case 'edicao_senha':
                    $subject = "Alteração de Senha";
                    $cabecalhoHTML = $this->getCabecalho($dadosMensagem, 'edicao_senha', $assunto);
                    $dadosAcessoHTML = $this->getDadosAcesso($dadosMensagem);
                break;
                
                case 'edicao_permissao_senha':
                    $subject = "Alteração de Senha e Permissões de Acesso";
                    $cabecalhoHTML = $this->getCabecalho($dadosMensagem, 'edicao_permissao_senha', $assunto);
                    $dadosAcessoHTML = $this->getDadosAcesso($dadosMensagem);
                    $permissoesHTML = $this->getPermissoes($dadosMensagem);
                break;
                
                default:
                    $subject = "Inclusão de Acesso ao Portal";
                    $linkPortal = $this->getLinkPortal();
                    $cabecalhoHTML = $this->getCabecalho($dadosMensagem, 'inclusao', $assunto, $linkPortal);
                    $dadosAcessoHTML = $this->getDadosAcesso($dadosMensagem);
                    $permissoesHTML = $this->getPermissoes($dadosMensagem);
            }
            
            $mensagem = $this->montaMensagemEmail($cabecalhoHTML, $dadosAcessoHTML, $permissoesHTML);
            $conteudo = $this->utilities->messageSendMail($row['CDFILIAL'], $assunto, $mensagem);
            
            $this->utilities->enviaEmail(null, $subject, $dadosMensagem['email'], $conteudo, $dadosMensagem['email']);
        } catch (\Exception $e) {
            $response->setError(new Error ($e->getMessage(),500));
        }
	}
	
    public function getCabecalho($dadosMensagem, $motivo, &$assunto, $linkPortal = '') 
    {
        $textoAdicional = '';
        $assunto = "Aviso Importante!";
        
        switch($motivo) {
            case 'exclusao':
                $textoAlterado = 'excluiu seu acesso ao';
                $textoAdicional = "<tr> 
                    					<td class='description'> 
                    						<div>A partir de agora você não conseguirá mais acessá-lo.</div>
                    					</td>
                    				</tr>";
            break;
            
            case 'edicao_permissao':
                $textoAlterado = 'alterou suas permissões em ';
            break;
            
            case 'edicao_senha':
                $textoAlterado = 'alterou sua senha de acesso ao';
                $textoAdicional = " <tr> 
                    					<td class='description'> 
                    						<div>A senha <b>deverá</b> ser alterada após o primeiro acesso.</div>
                    					</td>
                    				</tr>";
            break;
            
            case 'edicao_permissao_senha':
                $textoAlterado = 'alterou sua senha e suas permissões de acesso ao';
                $textoAdicional = " <tr> 
                    					<td class='description'> 
                    						<div>A senha <b>deverá</b> ser alterada após o primeiro acesso.</div>
                    					</td>
                    				</tr>";
            break;
            
            default:
                $linkHTML = '';
                
                if ($linkPortal) {
                    $linkHTML = "<tr>
                				    <td class='description'>
                				        <div style='padding-top: 10px;'>Para acessá-lo, clique neste <a style='color: #005A95 !important' href='https://www.portalecommerce.com' target='_blank'>link</a></div>
                				    <td>
                				</tr>";
                }
                
                $textoAlterado = 'incluiu seu acesso ao';
                $assunto = "<p class='bold' style='text-align: center'>Bem vindo ao <br/> Portal E-Commerce!</p>";
                $textoAdicional = " <tr> 
                    					<td class='description'> 
                    						<div>A senha <b>deverá</b> ser alterada após o primeiro acesso.</div>
                    					</td>
                    				</tr>"
                    				.$linkHTML;
        }
        
        return "<tr> 
					<td class='title description' style='padding-bottom: 10px;'> 
                        <b>" . $dadosMensagem['operador'] . "</b> " . $textoAlterado . " portal ecommerce em 
                        <b><span class='Object' id='OBJ_PREFIX_DWT71_com_zimbra_date'>" . $dadosMensagem['data'] . "</span></b>.
                    </td>
				</tr>"
				.$textoAdicional;
    }
	
	public function getPermissoes($dadosMensagem) 
	{
	    return "<tr> 
					<td class='title'> 
						<div style='padding-top: 20px; font-weight: bold; border-bottom: 1px solid #000;'>
							Permissões
						</div>
					</td>
				</tr>
                <tr> 
    				<td class='description'> 
    					<div class='divTable' style='padding-top: 5px;'> 
    						<div style='float: left;width: 50%;'>
    							Autorização de Fornecimento:
    						</div>
    						<div style='float: right;width: 50%;'>
    							<i>". $dadosMensagem['idAcessoAF'] ."</i>
    						</div>
    					</div>
    					<div class='divTable' style='padding-top: 23px;'> 
    						<div style='float: left;width: 50%;'>
    							Contas a Receber:
    						</div>
    						<div style='float: right;width: 50%;'>
    							<i>". $dadosMensagem['idAcessoCR'] ."</i>
    						</div>
    					</div>
    					<div class='divTable' style='padding-top: 23px;'> 
    						<div style='float: left;width: 50%;'>
    							Pedido de Cotação:
    						</div>
    						<div style='float: right;width: 50%;'>
    							<i>". $dadosMensagem['idAcessoCOT'] ."</i>
    						</div>
    					</div>
    				</td>
    			</tr>";
	}
	
    public function getDadosAcesso($dadosMensagem) 
    {
        return "<tr>
    				<td class='title' style='padding-top: 20px; font-weight: bold; border-bottom: 1px solid #000;'> 
    					<div>Dados de acesso</div>
    				</td>
    			</tr>
    			<tr> 
    				<td class='description'> 
    					<div class='divTable' style='padding-top: 5px;'> 
    						<div style='float: left;width: 20%;'>
    							E-mail:
    						</div>
    						<div style='float: right;width: 80%;'>
    							<i>". $dadosMensagem['email'] ."</i>
    						</div>
    					</div>
    					<div class='divTable' style='padding-top: 23px;'> 
    						<div style='float: left;width: 20%;'>
    							Senha:
    						</div>
    						<div style='float: right;width: 80%;'>
    							<i>". $dadosMensagem['senha'] ."</i>
    						</div>
    					</div>
    				</td>
    			</tr>";
    }
	
	public function montaMensagemEmail($cabecalhoHTML, $dadosAcessoHTML, $permissoesHTML)
	{
	    $mensagem = "<table cellpadding='0' cellspacing='0' style='width:548px'> 
				        <tbody>
        					" . $cabecalhoHTML . "
        					" . $dadosAcessoHTML . "
        					" . $permissoesHTML . "
        					<tr class='footer'> 
        						<td> 
        							<center> 
        								<br><p class='bold'>Email automático enviado pelo Portal E-Commerce.</p>
        							</center> 
        						</td>
        					</tr>
        				</tbody>
    				</table>";
	    
	    return $mensagem;
	}
	
    public function getLinkPortal()
    {
        $params = array(
            "P_IDATIVO" => 'S'
        );
        
        $sql = "SELECT 
                    MAX(DSLINKECOMMERCE) DSLINKECOMMERCE 
                FROM 
                    PARAMGERALECOMMERCE
                WHERE
                    IDATIVO = :P_IDATIVO";
        
        return $this->entityManager->getConnection()->fetchAll($sql, $params);
    }
        
}