function Utilities(ScreenService, ZhPreferences, Query, ZhFilterPreferences, validateEngine, templateManager, maskEngine, ZhUtil) {

/*global Util, Configuration, $*/

    this.changeTagRichText = function(fieldValue) {
        if (typeof(fieldValue) === 'string') {
            var newFieldValue;

            if (fieldValue.substr(0, 3) == '<p>') {
                newFieldValue = fieldValue.replace(/<p>/g, '').replace(/<\/p>/g, '<br>');
            }
            else if (fieldValue.substr(0, 3) == '<p ') {
                newFieldValue = fieldValue.replace(/<p/g, '<span').replace(/<\/p>/g, '</span><br>');
            }
            else {
                newFieldValue = fieldValue;
            }

            if (fieldValue.substr(-4) == '</p>') {
                newFieldValue = newFieldValue.slice('', -4);
            }

            return newFieldValue;
        }
        else {
            return fieldValue;
        }
    };
    
    this.startFilter = function(widget, currentRow) {
        return ZhPreferences.getDefaultWidgetPreferences(widget.id).then(function(result) {
            if (result && result.DEFAULT_FILTER) {
                ZhPreferences.getPreferences('filter', Query.build().where('WIDGET_ID').equals(widget.id)).then(function(filters) {
                    var defaultFilter = filters.filter(function(filter) {
                        return filter.ID == result.DEFAULT_FILTER;
                    })[0];
                    var filter = {
                        ID: defaultFilter.LABEL_TO_PREFERENCE || 'EDITED',
                        FILTER_ROW: JSON.parse(defaultFilter.FILTER_ROW)
                    };
                    currentRow = filter.FILTER_ROW;

                    ZhFilterPreferences.applyFilter(widget, filter).then(function() {
                        widget.appliedFilter = widget.appliedFilter || filter;
                        widget.appliedFilter.ID = result.DEFAULT_FILTER;
                        if (defaultFilter.LABEL_TO_PREFERENCE) {
                            widget._filterInfo[0].value = defaultFilter.LABEL_TO_PREFERENCE;
                        }
                    });
                });
            }
            else {
                if (Util.isUndefinedOrNull(currentRow) || Util.isEmptyObject(currentRow)) {
                    currentRow = buildFilterCurrentRow(widget);
                }
            }
            ZhFilterPreferences.openFilterWidget(widget, currentRow);
        });
    };

    var buildFilterCurrentRow = function(widget) {
        return getFilterRowWithDefaultValues(widget.fields);
    };

    var getFilterRowWithDefaultValues = function(filterFields) {
        let filterRow = {};
        filterFields.forEach(field => {
            let defaultValue = Util.getNestedProperty(field, ["filterProperties", "defaultValue"]) || field.defaultValue;
            if (!Util.isUndefinedOrNull(defaultValue)) {
                filterRow[field.name] = Util.evaluate(defaultValue);
            }
        });
        return filterRow;
    };

    function validaProduto(value, validationAttrs) {
        var filtro = templateManager.container.getActiveWidget();
        var retorno = {
            "valid": true
        };
        let field = validationAttrs.field;
        let fieldProduto;
        const final = filtro.currentRow.CDPRODFIN;
        const inicial = filtro.currentRow.CDPRODINI;

        if (value) {
            fieldProduto = field == "NMPRODFIN" ? inicial : final;
            if (fieldProduto) {
                if (inicial > final) {
                    return {
                        "valid": false,
                        "message": validationAttrs.message || ScreenService.i18n("Produto inicial deve ser menor ou igual a produto final.")
                    };
                }
            }
        }
        else if (field == "NMPRODINI" && Util.isEmptyOrBlank(filtro.currentRow.CDPRODINI) || field == "NMPRODFIN" && Util.isEmptyOrBlank(filtro.currentRow.CDPRODFIN)) {
            let msg = field == "NMPRODFIN" ? 'Produto final obrigatório' : 'Produto inicial obrigatório';
            return {
                "valid": false,
                "message": validationAttrs.message || ScreenService.i18n(msg)
            };
        }

        return retorno;
    }

    var registeredValidations = validateEngine.getMappedValidations();

    if (!registeredValidations.hasOwnProperty('validaProduto')) {
        validateEngine.registerValidation('validaProduto', validaProduto);
    }
    
    /* Cria máscara para o campo 'CDNMPRODUTO', onde é recebido o nome e o código
     * do produto concatenados.
     */
    var maskCodigoNomeProduto = function(value) {
        if (value) {
            var mascara = getLocalVar('CDPICTPROD');
            var tamanhoCodigo = mascara.replace(/\./g, '').length;
            var cdProduto = value.substring(0, tamanhoCodigo);
            var mask = {
                type: "fix",
                params: {
                    mask: mascara
                }
            };
            var cdProdutoFormatado = Util.applyMask(cdProduto, mask, maskEngine, ZhUtil);
            return value.replace(cdProduto, cdProdutoFormatado);
        }
    };

    maskEngine.registerMask('CDNMPROD',
        function() {},
        maskCodigoNomeProduto
    );
    
/*
 *  Retorna os períodos semestre atual, passado e próximo de acordo com a data atual
 */
    this.getSemestre = function(tempo) {
		let semestre = {
			'PASSADO': -6,
			'ATUAL': 0,
			'PROXIMO': 6
		};
		let mesAtual = moment().add(semestre[tempo], 'months').month();
		let trimestreInicial = 1;
		let trimestreFinal = 4;
        
        if(mesAtual <= 5) {
			trimestreInicial = 1;
			trimestreFinal = 2;
		} else {
			trimestreInicial = 3;
			trimestreFinal = 4;
		}
		
        return {
            "start":moment().add(semestre[tempo], 'months').quarter(trimestreInicial).startOf('quarter').format('DD/MM/YYYY'),
            "end":moment().add(semestre[tempo], 'months').quarter(trimestreFinal).endOf('quarter').format('DD/MM/YYYY')
        };
	};
	
	this.downloadArquivoNavegador = function(dados, nomeArquivo, tipo = 'text/plain') {
		
		const elemento = document.createElement('a');
		const dadosBlob = new Blob([dados], {type: tipo});
				
		elemento.setAttribute('href', window.URL.createObjectURL(dadosBlob));
		elemento.setAttribute('download', nomeArquivo);
		
		elemento.dataset.downloadurl = [tipo, elemento.download, elemento.href].join(':');
		
		elemento.click();
		elemento.remove();
		
	};

}

Configuration(function(ContextRegister) {
    ContextRegister.register('Utilities', Utilities);
});
